@@ -24,9 +24,9 @@ class Webhook_bot:
         """
 
         if self.webhook_type == 'wechat':
-            webhook_api_url="https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key={}".format(self.token)
+            webhook_api_url="https://qyapi.weixin.qq.com/cgi-bin/webhook/send?key={}".format(self.webhook_token)
         elif self.webhook_type == 'dingding':
-            webhook_api_url="https://oapi.dingtalk.com/robot/send?access_token={}".format(self.token)
+            webhook_api_url="https://oapi.dingtalk.com/robot/send?access_token={}".format(self.webhook_token)
         else:
             raise Exception("\'webhook_type\' 必须是 wechat 或 dingding")
 
